controller

package
v0.0.0-...-78011d0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 19, 2020 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetVaultHandler

func GetVaultHandler(w http.ResponseWriter, r *http.Request)

Returns a Vault to a user

func LoginHandler

func LoginHandler(w http.ResponseWriter, r *http.Request)

Login method; checks id and returns auth token

func RegisterHandler

func RegisterHandler(w http.ResponseWriter, r *http.Request)

Registers a user. Takes in a vault key, email, and empty accounts array Checks if the email already exists, if so, send back error code

func UpdateHandler

func UpdateHandler(w http.ResponseWriter, r *http.Request)

"Updates" a Users Vault (Actually Replaces the entire users vault with the updated one)

Types

This section is empty.

Jump to