Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetVaultHandler ¶
func GetVaultHandler(w http.ResponseWriter, r *http.Request)
Returns a Vault to a user
func LoginHandler ¶
func LoginHandler(w http.ResponseWriter, r *http.Request)
Login method; checks id and returns auth token
func RegisterHandler ¶
func RegisterHandler(w http.ResponseWriter, r *http.Request)
Registers a user. Takes in a vault key, email, and empty accounts array Checks if the email already exists, if so, send back error code
func UpdateHandler ¶
func UpdateHandler(w http.ResponseWriter, r *http.Request)
"Updates" a Users Vault (Actually Replaces the entire users vault with the updated one)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.